==> pysyd-5.9.90.tar.gz: pysyd-5.9.90/README.md <==
<div align="center">
<img src="docs/_static/latex.png" width="70%">

## **Automated Measurements of Global Asteroseismic Parameters**

[![PyPI](https://img.shields.io/pypi/v/pysyd)](https://pypi.org/project/pysyd/)
[![Documentation](https://readthedocs.org/projects/pysyd/badge/?version=latest)](https://pysyd.readthedocs.io/en/latest/?badge=latest)
[![License: MIT](https://img.shields.io/badge/License-MIT-red.svg)](https://github.com/ashleychontos/pySYD/blob/master/LICENSE)
[![arXiv](https://img.shields.io/badge/arXiv-2108.00582-b31b1b.svg)](https://arxiv.org/abs/2108.00582)
[![JOSS](https://joss.theoj.org/papers/6465a9dd3141c207175f200c7f891f1e/status.svg)](https://joss.theoj.org/papers/6465a9dd3141c207175f200c7f891f1e)
[![PyPI downloads](https://img.shields.io/pypi/dm/pysyd?color=purple)](https://pypistats.org/packages/pysyd)
<a href="https://ascl.net/2111.017"><img src="https://img.shields.io/badge/ascl-2111.017-blue.svg?colorB=262255" alt="ascl:2111.017" /></a>

<a href="https://github.com/ashleychontos/pySYD/graphs/contributors"><img src="https://contrib.rocks/image?repo=ashleychontos/pySYD" /></a>
</div>

--------------------------------------------------------------------------------

## Documentation

The documentation for `pySYD` can be found on [Read the Docs](https://pysyd.readthedocs.io).

## Attribution

If you make use of `pySYD` in your work, please cite our [JOSS paper](https://arxiv.org/abs/2108.00582):

    @ARTICLE{2021arXiv210800582C,
           author = {{Chontos}, Ashley and {Huber}, Daniel and {Sayeed}, Maryum and {Yamsiri}, Pavadol},
            title = "{$\texttt{pySYD}$: Automated measurements of global asteroseismic parameters}",
          journal = {arXiv e-prints},
         keywords = {Astrophysics - Solar and Stellar Astrophysics, Astrophysics - Instrumentation and Methods for Astrophysics},
             year = 2021,
            month = aug,
              eid = {arXiv:2108.00582},
            pages = {arXiv:2108.00582},
    archivePrefix = {arXiv},
           eprint = {2108.00582},
     primaryClass = {astro-ph.SR}, 
           adsurl = {https://ui.adsabs.harvard.edu/abs/2021arXiv210800582C},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }
    
If applicable, please also use our [ASCL listing](https://ui.adsabs.harvard.edu/abs/2021ascl.soft11017C) as a software citation:

    @MISC{2021ascl.soft11017C,
           author = {{Chontos}, Ashley and {Huber}, Daniel and {Sayeed}, Maryum and {Yamsiri}, Pavadol},
            title = "{pySYD: Measuring global asteroseismic parameters}",
         keywords = {Software},
             year = 2021,
            month = nov,
              eid = {ascl:2111.017},
            pages = {ascl:2111.017},
    archivePrefix = {ascl},
           eprint = {2111.017},
           adsurl = {https://ui.adsabs.harvard.edu/abs/2021ascl.soft11017C},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }

## License

&copy; 2019-2022 Ashley Chontos and contributors. <br/>
`pySYD` is free software made available under the [MIT license](LICENSE.md).

## Contribution

Our [list](docs/AUTHORS.rst) of contributors continues to grow! <br/> 
If you'd like to be a part of that, please see [our guide](CONTRIBUTING.md) for contributing.

==> pysyd-6.10.0.tar.gz: pysyd-6.10.0/README.md <==
<div align="center">
<img src="docs/_static/latex.png" width="70%">

## **Automated Measurements of Global Asteroseismic Parameters**

[![PyPI](https://img.shields.io/pypi/v/pysyd)](https://pypi.org/project/pysyd/)
![tests](https://github.com/ashleychontos/pySYD/actions/workflows/tests.yml/badge.svg)
[![Documentation](https://readthedocs.org/projects/pysyd/badge/?version=latest)](https://pysyd.readthedocs.io/en/latest/?badge=latest)
[![arXiv](https://img.shields.io/badge/arXiv-2108.00582-b31b1b.svg)](https://arxiv.org/abs/2108.00582)
[![JOSS](https://joss.theoj.org/papers/6465a9dd3141c207175f200c7f891f1e/status.svg)](https://joss.theoj.org/papers/6465a9dd3141c207175f200c7f891f1e)
[![PyPI downloads](https://img.shields.io/pypi/dm/pysyd?color=purple)](https://pypistats.org/packages/pysyd)
<a href="https://ascl.net/2111.017"><img src="https://img.shields.io/badge/ascl-2111.017-blue.svg?colorB=262255" alt="ascl:2111.017" /></a>

<a href="https://github.com/ashleychontos/pySYD/graphs/contributors"><img src="https://contrib.rocks/image?repo=ashleychontos/pySYD" /></a>
</div>

--------------------------------------------------------------------------------

## Documentation

The documentation for `pySYD` can be found [here](https://pysyd.readthedocs.io).

## Attribution

If you make use of `pySYD` in your work, please cite [Chontos et al. (2021)](https://arxiv.org/abs/2108.00582):

    @ARTICLE{2021arXiv210800582C,
           author = {{Chontos}, Ashley and {Huber}, Daniel and {Sayeed}, Maryum and {Yamsiri}, Pavadol},
            title = "{$\texttt{pySYD}$: Automated measurements of global asteroseismic parameters}",
          journal = {arXiv e-prints},
         keywords = {Astrophysics - Solar and Stellar Astrophysics, Astrophysics - Instrumentation and Methods for Astrophysics},
             year = 2021,
            month = aug,
              eid = {arXiv:2108.00582},
            pages = {arXiv:2108.00582},
    archivePrefix = {arXiv},
           eprint = {2108.00582},
     primaryClass = {astro-ph.SR}, 
           adsurl = {https://ui.adsabs.harvard.edu/abs/2021arXiv210800582C},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }

## License

&copy; 2019-2022 Ashley Chontos and contributors. <br/>
`pySYD` is free software made available under the [MIT license](LICENSE.md).

## Contribution

Our [list](docs/AUTHORS.rst) of contributors continues to grow! <br/> 
If you'd like to be a part of that, please see [our guide](CONTRIBUTING.md) for contributing.
